@@ -4,4 +4,5 @@ from .base import (NodeGraph,
                    EVT_GSNODEGRAPH_NODESELECT,
                    EVT_GSNODEGRAPH_NODEDISCONNECT,
                    EVT_GSNODEGRAPH_NODECONNECT,
-                   EVT_GSNODEGRAPH_MOUSEZOOM)
+                   EVT_GSNODEGRAPH_MOUSEZOOM,
+                   EVT_GSNODEGRAPH_ADDNODEBTN)
